@@ -1,13 +1,25 @@
 ##' Calculate disproportionate impact per the proportionality index (PI) method.
 ##'
-##' This function determines disproportionate impact based on the proportionality index (PI) method, as described in \href{https://www.cccco.edu/-/media/CCCCO-Website/About-Us/Divisions/Digital-Innovation-and-Infrastructure/Network-Operations/Accountability/Files/GUIDELINES-FOR-MEASURING-DISPROPORTIONATE-IMPACT-IN-EQUITY-PLANS.ashx}{this} reference from the California Community Colleges Chancellor's Office.  It assumes that a higher rate is good ("success").  For rates that are deemed negative (eg, rate of drop-outs, high is bad), then consider looking at the converse of the non-success (eg, non drop-outs, high is good) instead in order to leverage this function properly.
+##' This function determines disproportionate impact based on the proportionality index (PI) method, as described in \href{https://www.cccco.edu/-/media/CCCCO-Website/Files/DII/guidelines-for-measuring-disproportionate-impact-in-equity-plans-tfa-ada.pdf}{this} reference from the California Community Colleges Chancellor's Office.  It assumes that a higher rate is good ("success").  For rates that are deemed negative (eg, rate of drop-outs, high is bad), then consider looking at the converse of the non-success (eg, non drop-outs, high is good) instead in order to leverage this function properly.
 ##' @title Calculate disproportionate impact per the proportionality index (PI) method.
 ##' @param success A vector of success indicators (\code{1}/\code{0} or \code{TRUE}/\code{FALSE}) or an unquoted reference (name) to a column in \code{data} if it is specified.  It could also be a vector of counts, in which case \code{weight} should also be specified (group size).
 ##' @param group A vector of group names of the same length as \code{success} or an unquoted reference (name) to a column in \code{data} if it is specified.
-##' @param cohort (Optional) A vector of cohort names of the same length as \code{success} or an unquoted reference (name) to a column in \code{data} if it specified.  disproportionate impact is calculated for every group within each cohort.  When \code{cohort} is not specified, then the analysis assumes a single cohort.
-##' @param weight (Optional) A vector of case weights of the same length as \code{success} or an unquoted reference (name) to a column in \code{data} if it specified.  If \code{success} consists of counts instead of success indicators (1/0), then \code{weight} should also be specified to indicate the group size.
+##' @param cohort (Optional) A vector of cohort names of the same length as \code{success} or an unquoted reference (name) to a column in \code{data} if it is specified.  disproportionate impact is calculated for every group within each cohort.  When \code{cohort} is not specified, then the analysis assumes a single cohort.
+##' @param weight (Optional) A vector of case weights of the same length as \code{success} or an unquoted reference (name) to a column in \code{data} if it is specified.  If \code{success} consists of counts instead of success indicators (1/0), then \code{weight} should also be specified to indicate the group size.
 ##' @param data (Optional) A data frame containing the variables of interest.  If \code{data} is specified, then \code{success}, \code{group}, and \code{cohort} will be searched within it.
-##' @return A data frame consisting of: cohort (if used), group, n (sample size), success (number of successes for the cohort-group), pct_success (proportion of successes attributed to the group within the cohort), pct_group (proportion of sample attributed to the group within the cohort), and di_prop_index (ratio of pct_success to pct_group).  When di_prop_index < 1, then there are signs of disproportionate impact.
+##' @param di_prop_index_cutoff A numeric value between 0 and 1 that is used to determine disproportionate impact if the proportionality index falls below this threshold; defaults to 0.80.
+##' @return A data frame consisting of:
+##' \itemize{
+##'   \item \code{cohort} (if used),
+##'   \item \code{group},
+##'   \item \code{n} (sample size),
+##'   \item \code{success} (number of successes for the cohort-group),
+##'   \item \code{pct_success} (proportion of successes attributed to the group within the cohort),
+##'   \item \code{pct_group} (proportion of sample attributed to the group within the cohort),
+##'   \item \code{di_prop_index} (ratio of pct_success to pct_group), and
+##'   \item \code{di_indicator} (1 if \code{di_prop_index < di_prop_index_cutoff}).
+##' }
+##' When \code{di_prop_index < 1}, then there are signs of disproportionate impact.
 ##' @examples
 ##' library(dplyr)
 ##' data(student_equity)
@@ -17,7 +29,7 @@
 ##' @export
 ##' @import dplyr
 ##' @importFrom rlang !! enquo
-di_prop_index <- function(success, group, cohort, weight, data) {
+di_prop_index <- function(success, group, cohort, weight, data, di_prop_index_cutoff=0.80) {
   if (!missing(data)) {
     eq_success <- enquo(success)
     success <- data %>% ungroup %>% mutate(success=!!eq_success) %>% select(success) %>% unlist
@@ -27,6 +39,7 @@ di_prop_index <- function(success, group, cohort, weight, data) {
   # Check if success is binary or logical and that there are no NA's
   #stopifnot(success %in% c(1, 0))
   stopifnot(!is.na(success), success>=0) # can be counts
+  stopifnot(di_prop_index_cutoff >= 0, di_prop_index_cutoff <= 1)
 
   # Check if cohort is specified
   if (missing(cohort)) {
@@ -52,13 +65,18 @@ di_prop_index <- function(success, group, cohort, weight, data) {
 
   # Calculate
   df <- tibble(cohort, group, success, weight)
-  pct_success <- pct_group <- NULL # to resolve CRAN NOTE: no visible binding for global variable
+  pct_success <- pct_group <- di_indicator <- NULL # to resolve CRAN NOTE: no visible binding for global variable
   dResults <- df %>%
     group_by(cohort, group) %>%
     summarize(n=sum(weight), success=sum(success)) %>%
     ungroup %>%
     group_by(cohort) %>% 
-    mutate(pct_success=success/sum(success), pct_group=n/sum(n), di_prop_index=pct_success/pct_group) %>% 
+    mutate(pct_success=success/sum(success)
+         , pct_group=n/sum(n)
+         , di_prop_index=pct_success/pct_group
+         , di_indicator=ifelse(di_prop_index < di_prop_index_cutoff, 1, 0)
+         , di_indicator=ifelse(is.nan(pct_success), 0, di_indicator) # pct_success when there are zero success for everyone; in this case, there is no DI
+           ) %>% 
     ungroup %>%
     arrange(cohort, group)
 
